# /www/survsimp/admin/question-delete.tcl
ad_page_contract {

    Delete a section from a survey
    (or ask for confirmation if there are responses).

    @param  section_id   section we're about to delete

    @author koljalehmann@uni.de
    @date   August 8th, 2003
    @cvs-id $Id: section-delete.tcl,v 1.1 2003/09/19 16:48:04 rmello Exp $
} {

    section_id:integer
}

ad_require_permission $section_id admin

get_survey_info -section_id $section_id
set survey_id $survey_info(survey_id)

set n_questions [db_string section_number_questions {} ]

set error 0
if {$n_questions==0} {
    # section does not contain any question, just delete it
    db_transaction {
	db_dml section_reorder {}
	set conditions [db_list conditions {}]
	db_dml delete_branches {}
	foreach condition_id $conditions {
	    db_dml delete_condition {}
	}
	if {[db_0or1row replacement_section {}]} {
	    # the attribute "after" of survey_branches is not really used, will disappear soon
	    # if a new first_section cannot be found, there shouldn't be any branches
	    db_dml branch_reorder {}
	}
	db_exec_plsql section_delete {}
    } on_error {
	ad_form -name warning -action "one" -form {
	    {survey_id:text(hidden) {value $survey_id}}
	    {warning:text(inform) {label "Warning"} {value "Unable to delete section. This was the Error: <pre>$errmsg</pre>"}}
	}
	set context_bar [ad_context_bar "Delete Section"]    
	ad_return_template
	set error 1
    }
} else {
    # there are still questions in the section. give a warning
    ad_form -name warning -action "one" -form {
	{survey_id:text(hidden) {value $survey_id}}
	{warning:text(inform) {label "Warning"} {value "Unable to delete section. It does contain questions, which must be deleted first"}}
    }
    set context_bar [ad_context_bar "Delete Section"]    
    ad_return_template
    set error 1
}

if {!$error} {
    ad_returnredirect "one?survey_id=$survey_id"
}
