ad_page_contract {

    Allow the user to add a custom template for a section

    @param   section_id   section we're adding a template to

    @author  koljalehmann@uni.de
    @date    Jul, 7, 2003
    @cvs-id  $Id: section-template-ae.tcl,v 1.1 2003/09/19 16:48:04 rmello Exp $
} {
    section_id:integer
}

get_section_info -section_id $section_id
set section_name $section_info(name)
set survey_id $section_info(survey_id)
ad_require_permission $survey_id admin

# If there is already a custom template for the section, load it,
# else generate a new one
set template_filename "[template::get_resource_path]/forms/survey/sections/${section_id}.adp"

if {[file exists $template_filename]} {
    set templatesource [template::util::read_file $template_filename]
} else {
    set templatesource "
     <tr>
      <td colspan=2 bgcolor=#eeeeee>
        <b>$section_info(name)</b></td>
     </tr>
     <tr>
      <td colspan=2 bgcolor=#eeeeee>
       $section_info(description)</td>
     </tr>
    "

    # get all the questions and insert them into the template
    db_foreach questions "" {
	if {$presentation_type=="radio" || $presentation_type=="checkbox"} {
	    # radio and checkbox questions need an extra treatment
	    # the choices are generated with a <formgroup> tag
	    set widget_code "
   <formgroup id=\"response_to_question.$question_id\">
      @formgroup.widget;noquote@
      @formgroup.label@
   </formgroup>"
	} else {
	    set widget_code "
   <formwidget id=\"response_to_question.$question_id\">"
	}
	append templatesource "<tr>
  <td>[ad_decode $required_p "t" "<span style=\"color: \#f00;\">*</span>" ""]<b>$question_text</b></td>
  <td>$widget_code
  </td>
</tr>"
    }
}

ad_form -name edit_template -form {
    {section_id:text(hidden) {value $section_id}}
    {template_source:text(textarea) {label "Template Code"} {html {rows 20 cols 80}} {value $templatesource}}
    {apply:text(submit) {label "Apply"}}
    {revert:text(submit) {label "Erase custom template"}}
} -on_submit {
    if {$apply=="Apply"} {
	# write edited template into a file
	set file_handle [open $template_filename w]
	puts $file_handle $template_source
	close $file_handle	
    } 
    if {$revert=="Erase custom template"} {
	# erase template file
	if {[file exists $template_filename]} {
	    file delete $template_filename
	}
	ad_returnredirect "section-template-ae?section_id=$section_id"
    }	
}

ad_form -name preview_section -form {
    {section_id:text(hidden) {value $section_id}}
}

survey_section_add_to_form preview_section $section_id

set context_bar [ad_context_bar "Edit Section"]

set style "survey/standard"
db_0or1row get_style ""

ad_return_template

